@@ -79,6 +79,7 @@ sub test_assert {
     $self->assert($coderef, 'a', 'a');
     $self->assert([]);
     $self->assert([ 'foo', 7 ]);
+    my $re_foo = qr/foo/; $re_foo = "$re_foo";
     $self->check_failures(
         'Boolean assertion failed' => [ __LINE__, sub { shift->assert(undef) } ],
         'Boolean assertion failed' => [ __LINE__, sub { shift->assert(0)   } ],
@@ -86,7 +87,7 @@ sub test_assert {
 
         'bang'  => [ __LINE__, sub { shift->assert(0, 'bang')              } ],
         'bang'  => [ __LINE__, sub { shift->assert('', 'bang')             } ],
-        "'qux' did not match /(?-xism:foo)/"
+        "'qux' did not match /$re_foo/"
                 => [ __LINE__, sub { shift->assert(qr/foo/, 'qux')         } ],
         'bang'  => [ __LINE__, sub { shift->assert(qr/foo/, 'qux', 'bang') } ],
         'a ne b'=> [ __LINE__, sub { shift->assert($coderef, 'a', 'b')     } ],
@@ -259,6 +260,7 @@ sub test_ok_equals {
 sub test_ok_not_equals {
     my $self = shift;
     my $adder = sub { 2+2 };
+    my $re_x = qr/x/; $re_x = "$re_x";
     my @checks = (
         # interface is ok(GOT, EXPECTED);
         q{expected 1, got 0}                => [ 0,      1       ], 
@@ -269,7 +271,7 @@ sub test_ok_not_equals {
         q{expected '', got 'foo'}           => [ 'foo',  ''      ], 
         q{expected 'foo', got ''}           => [ '',     'foo'   ], 
         q{expected 5, got 4}                => [ $adder, 5       ], 
-        q{'foo' did not match /(?-xism:x)/} => [ 'foo',  qr/x/   ], 
+        qq{'foo' did not match /$re_x/}     => [ 'foo',  qr/x/   ], 
     );
     my @tests = ();
     while (@checks) {
